

::: telliot_core.queries.query.OracleQuery

::: telliot_core.queries.price.spot_price.SpotPrice

::: telliot_core.queries.legacy_query.LegacyRequest

::: telliot_core.queries.string_query.StringQuery
